# LensKit wrapper for implicit

> [!NOTE]
> This package is deprecated — install `lenskit[implicit]` instead.

The `lenskit-implicit` package provides [LensKit][] wrappers for the
implicit-feedback matrix factorization algorithms found in Ben Frederickson's
[implicit][] package.

> [!NOTE]
> This package is *not* required for implicit-feedback recommendation in
> LensKit — that is well-supported by a variety of algorithms. It is just
> a bridge to the [implicit][] package to facilitate experiments using
> that software.

[implicit]: https://pypi.org/project/implicit
[LensKit]: https://lkpy.lenskit.org
